//---------------------------------------------------------------------------
// Arquivo:    DLLLeitura.h              Data: 03/03/2008
// Descrio:  Declarao das funes e das constantes utilizadas pela
//             verso 01.00.00 da DLL de Leitura de Memrias de ECFs com o
//             protocolo de comunicao FiscNET.
//

#ifndef _DLLLeitura_H
#define _DLLLeitura_H

#include <windows.h>

//---------------------------------------------------------------------------
// Declarao de constantes utilizadas pela DLL de Leitura de Memrias
//---------------------------------------------------------------------------


//---------------------------------------------------------------------------
// Aes possveis retornadas pela funo tratadora de erros

// Em caso de erro, operao que gerou o erro deve ser repetida
#define DLLErroAcaoRetentativa                -1

// Operao de leitura deve ser abortada.
#define DLLErroAcaoCancela                    0


//---------------------------------------------------------------------------
//  Constantes relativas s situaes da leitura em andamento

// Comunicao ainda no iniciou
#define  DLLStatInicial                            0x0000

// DLL de Leitura st tentando carregar a DLL de comunicao.
#define  DLLStatCargaDLL                           0x0010

// Indica que est efetuando a leitura de informaes do ECF
#define  DLLStatInfoECF                            0x0020

// Abrindo (ou criando) arquivo binrio
#define  DLLStatLendoArquivo                       0x0030 

// Obtendo as informaes da Memria Fiscal
#define  DLLStatInfoMF                             0x0040

// Obtendo as informaes da Memria de Fita-Detalhe
#define  DLLStatInfoMFD                            0x0050

// Obtendo as informaes da Memria de Fita-Detalhe
#define  DLLStatInfoMFD                            0x0050

// Lendo os dados da Memria Fiscal
#define  DLLStatLendoMF                            0x0060

// Lendo os dados da Memria de Fita-Detalhe
#define  DLLStatLendoMFD                           0x0070

// Encerrando a execuo da leitura
#define  DLLStatEncerrando                         0x0080

// Leitura foi encerrada com sucesso
#define  DLLStatEncerradaOK                        0x0100

// Leitura foi encerrada com erro
#define  DLLStatEncerradaNOK                       0x0200

// Indica que est em processo de tratamento de erro
#define  DLLStatErro                               0x0210

// Cancelando a execuo da leitura
#define  DLLStatCancelando                         0x0300

// Leitura foi encerrada por cancelamento
#define  DLLStatCancelada                          0x0400


//---------------------------------------------------------------------------
//  Constantes relativas ao status atual da DLL de Leitura de Memrias


//---------------------------------------------------------------------------
//  Constantes relativas aos limites da DLL de Leitura de Memrias

// Tamanho mximo do texto descritivo do status atual da leitura
#define DLL_READ_MAX_SITUACAO                     128 



//---------------------------------------------------------------------------
//  Constantes relativas aos erros gerados pela DLL de Leitura de Memrias


// Indicador de que no houve nenhum erro
#define DLLErroOK                                 0x0000

// **** Erros com possibilidade de efetuar retentativa ****

// Arquivo de dados j existe mas no pode ser aberto
#define DLLErroAbreArquivo                        0x1001


// **** Lista de erros que no podem ser contornados ****

// DLL de comunicao DLL-G2.DLL no pde ser carregada.
#define DLLErroCargaDLL                           0x4001

// Canal de comunicao indicado no pde ser aberto.
#define DLLErroCanalCOM                           0x4002

// Formato do arquivo binrio  invlido
#define DLLErroBinarioInvalido                    0x4003

// Erro de leitura no arquivo binrio
#define DLLErroLeituraArquivo                     0x4004

// Erro de escrita no arquivo binrio
#define DLLErroEscritaArquivo                     0x4005

// Arquivo binrio indicado no pertence a este ECF
#define DLLErroBinarioECF                         0x4006

// ECF conectado  porta serial no  o ECF indicado
#define DLLErroECFInvalido                        0x4007

// Faltou memria RAM
#define DLLErroFaltaRAM                           0x4008

// Arquivo de texto no pde ser criado
#define DLLErroCriaArquivo                        0x4009

// Arquivo binrio est incompleto. Gerao do arquivo de texto no  possvel.
#define DLLErroArquivoIncompleto                  0x400a


//---------------------------------------------------------------------------
// Estruturas de dados utilizadas na interface com a DLL de Leitura
//---------------------------------------------------------------------------

// Estrutura preenchida pela funo de leitura de status
typedef struct
{
  int  nTamanhoStatus;      // Tamanho, em bytes, desta estrutura. Deve ser
                            // preenchida pelo aplicativo antes da chamada
                            //  funo DLLReadStatus.

  int  nSituacaoAtual;      // Atual status da leitura (cdigo numrico).
  int  nCodigoErro;         // Caso esteja interrompida por erro, indica
                            // o cdigo do erro. Neste caso a descrio
                            // da atual situao da leitura estar
                            // indicando a descrio completa do erro.

  long lnTamanhoLeitura;    // Tamanho total desta etapa da leitura.
  long lnProgressoLeitura;  // Progresso atual desta etapa da leitura.

  char szSituacaoAtual[DLL_READ_MAX_SITUACAO]; // Descrio da atual etapa
                                               // da leitura em andamento.
} DLLReadStatusData;




//---------------------------------------------------------------------------
// Funes exportadas pela DLL de Leitura de Memrias
//---------------------------------------------------------------------------

extern "C"
{
// Define o baud-rate pretendido para a prxima leitura a ser realizada
void __cdecl DLLReadDefineBaudRate (long lnBaudRate);

// Define a funo do aplicativo que ir tratar os eventos gerados pela prxima leitura
void __cdecl DLLReadDefineTrataErro (int (*pTratadora) (long lnErro, char *szDescricao, bool bErroNaoFatal));

// Retorna o atual status da leitura em andamento
int __cdecl DLLReadStatus (DLLReadStatusData *pStatusData);

// Ordena o cancelamento da leitura em execuo
void __cdecl DLLReadCancelaLeitura (void);

// Executa a leitura das memrias do ECF conectado a <szPortaSerial>, gravando
// os dados no arquivo <szNomeArquivo>, podendo retornar imediatamente ou
// aguardando o trmino das leituras, dependendo do parmetro <bArguardaConcluirLeitura>.
int __cdecl DLLReadLeMemorias (char *szPortaSerial, char *szNomeArquivo,
                              char *szSerieECF, char bArguardaConcluirLeitura);

// Retorna a verso da DLL para a string apontada por <szVersao>.
// Ateno. A rea apontada por <szVersao> deve ter, no mnimo, 10 bytes de tamanho.
void __cdecl DLLVersao (char *szVersao);

};



//---------------------------------------------------------------------------

#endif // _DLLLeitura_H

